@@ -3,12 +3,12 @@ use bitvec::prelude::*;
 use num::ToPrimitive;
 use std::convert::TryInto;
 
-impl<'a> ReadType<'a> for BitVec<Lsb0, u8> {
-	type ReadType = Pointer<&'a BitSlice<Lsb0, u8>>;
+impl<'a> ReadType<'a> for BitVec<u8, Lsb0> {
+	type ReadType = Pointer<&'a BitSlice<u8, Lsb0>>;
 }
 
-impl<'a> Read<'a> for &'a BitSlice<Lsb0, u8> {
-	type Output = &'a BitSlice<Lsb0, u8>;
+impl<'a> Read<'a> for &'a BitSlice<u8, Lsb0> {
+	type Output = &'a BitSlice<u8, Lsb0>;
 	fn read(bytes: &'a [u8], position: Position<Self>) -> Self::Output {
 		let position = position.cast();
 		let bit_len = PointerType::read(bytes, position);
@@ -17,17 +17,17 @@ impl<'a> Read<'a> for &'a BitSlice<Lsb0, u8> {
 		let position = *position + PointerType::STATIC_SIZE;
 		let position = position as usize;
 		let slice = &bytes[position..position + byte_len];
-		let bit_slice = BitSlice::from_slice(slice).unwrap();
+		let bit_slice = BitSlice::from_slice(slice);
 		&bit_slice[..bit_len]
 	}
 }
 
-impl WriteType for BitVec<Lsb0, u8> {
-	type WriteType = Position<BitVec<Lsb0, u8>>;
+impl WriteType for BitVec<u8, Lsb0> {
+	type WriteType = Position<BitVec<u8, Lsb0>>;
 }
 
-impl Write for BitVec<Lsb0, u8> {
-	type Output = BitVec<Lsb0, u8>;
+impl Write for BitVec<u8, Lsb0> {
+	type Output = BitVec<u8, Lsb0>;
 	fn write(&self, writer: &mut crate::Writer) -> Position<Self::Output> {
 		let position = writer.position();
 		let bit_len: PointerType = self.len().try_into().unwrap();
